BcsrSections

Struct BcsrSections 

pub struct BcsrSections<'view, OffsetWord, VertexWord, RelationWord>
where OffsetWord: BcsrWord, VertexWord: BcsrWord, RelationWord: BcsrWord,
{ pub head_offsets: &'view [OffsetWord], pub head_participants: &'view [VertexWord], pub tail_offsets: &'view [OffsetWord], pub tail_participants: &'view [VertexWord], pub vertex_outgoing_offsets: &'view [OffsetWord], pub vertex_outgoing_hyperedges: &'view [RelationWord], pub vertex_incoming_offsets: &'view [OffsetWord], pub vertex_incoming_hyperedges: &'view [RelationWord], }
Borrowed input slices for a bipartite-CSR hypergraph view.

Offset slices use OffsetWord and decode to the incidence index width. Participant value slices use VertexWord and decode to the vertex index width. Vertex-major relation slices use RelationWord and decode to the relation index width.

Performance

perf: unspecified; this is a borrowed parameter struct.

Fields

head_offsets: &'view [OffsetWord]

Hyperedge-major head offsets, length hyperedge_count + 1.

head_participants: &'view [VertexWord]

Flat vertex IDs in head sets, length P_head.

tail_offsets: &'view [OffsetWord]

Hyperedge-major tail offsets, length hyperedge_count + 1.

tail_participants: &'view [VertexWord]

Flat vertex IDs in tail sets, length P_tail.

vertex_outgoing_offsets: &'view [OffsetWord]

Vertex-major outgoing offsets, length vertex_count + 1.

vertex_outgoing_hyperedges: &'view [RelationWord]

Flat hyperedge IDs where the vertex is in head, length P_outgoing.

vertex_incoming_offsets: &'view [OffsetWord]

Vertex-major incoming offsets, length vertex_count + 1.

vertex_incoming_hyperedges: &'view [RelationWord]

Flat hyperedge IDs where the vertex is in tail, length P_incoming.